# Webhook Loghandlers
Handlers for the python logging module to send logs to discord/slack webhooks.  

[![PyPI version](https://badge.fury.io/py/webhook-loghandlers.svg)](https://badge.fury.io/py/webhook-loghandlers)
